@@ -26,6 +26,7 @@
 #include "resource.h"
 
 #include <Soprano/Vocabulary/NAO>
+#include <Soprano/Vocabulary/RDF>
 #include <Soprano/Model>
 #include <Soprano/StatementIterator>
 #include <Soprano/NodeIterator>
@@ -89,9 +90,19 @@ Nepomuk2::Tag& Nepomuk2::Tag::operator=( const Tag& res )
 QList<Nepomuk2::Resource> Nepomuk2::Tag::tagOf() const
 {
     Soprano::Model* model = ResourceManager::instance()->mainModel();
-    QList<Soprano::Node> list = model->listStatements( Soprano::Node(), NAO::hasTag(), resourceUri() ).iterateSubjects().allNodes();
-    QList<Nepomuk2::Resource> resources;
+    QList<Soprano::Node> list = model->listStatements( Soprano::Node(), NAO::hasTag(), uri() ).iterateSubjects().allNodes();
+    QList<Resource> resources;
     foreach(const Soprano::Node& node, list)
         resources << node.uri();
     return resources;
 }
+
+QList< Nepomuk2::Tag > Nepomuk2::Tag::allTags()
+{
+    Soprano::Model* model = ResourceManager::instance()->mainModel();
+    QList<Soprano::Node> list = model->listStatements( Soprano::Node(), RDF::type(), NAO::Tag() ).iterateSubjects().allNodes();
+    QList<Tag> tags;
+    foreach(const Soprano::Node& node, list)
+        tags << node.uri();
+    return tags;
+}
